@@ -5,7 +5,7 @@ from itertools import chain
 
 # TODO: Import only the official interface
 from output import *
-from config import header_and_libs_from_pkgconfig
+from config import header_and_libs_from_pkgconfig, get_swig_version
 from paths import *
 from signatures import *
 from cache import *
@@ -77,8 +77,9 @@ def recompile(modulename, module_path, setup_name, new_compilation_checksum):
             return
     
     # Verify that SWIG is on the system
-    (swig_stat, swig_out) = get_status_output("swig -version")
-    if swig_stat != 0:
+    try:
+        get_swig_version()
+    except OSError:
         instant_error("In instant.recompile: Could not find swig!"\
             " You can download swig from http://www.swig.org")
     
@@ -87,7 +88,7 @@ def recompile(modulename, module_path, setup_name, new_compilation_checksum):
     compile_log_file = open(compile_log_filename, "w")
     try:
         # Build module
-        cmd = "python %s build_ext" % setup_name
+        cmd = "python %s build_ext install --install-platlib=." % setup_name
         instant_info("--- Instant: compiling ---")
         instant_debug("cmd = %s" % cmd)
         ret, output = get_status_output(cmd)
@@ -98,18 +99,6 @@ def recompile(modulename, module_path, setup_name, new_compilation_checksum):
                 os.remove(compilation_checksum_filename)
             instant_error("In instant.recompile: The module did not "\
                 "compile, see '%s'" % compile_log_filename)
-        
-        # 'Install' module
-        cmd = "python %s install --install-platlib=." % setup_name
-        instant_debug("cmd = %s" % cmd)
-        ret, output = get_status_output(cmd)
-        compile_log_file.write(output)
-        compile_log_file.flush()
-        if ret != 0:
-            if os.path.exists(compilation_checksum_filename):
-                os.remove(compilation_checksum_filename)
-            instant_error("In instant.recompile: Could not 'install' "\
-                "the module, see '%s'" % compile_log_filename)
     finally:
         compile_log_file.close()
     
@@ -501,3 +490,66 @@ def build_module(modulename=None, source_directory=".",
     instant_error("In instant.build_module: Should never reach this point!")
     # end build_module
 
+
+def build_module_vtk(c_code, cache_dir=None): 
+    original_path = os.getcwd()
+    cache_dir = validate_cache_dir(cache_dir)
+    signature = modulename_from_checksum(compute_checksum(c_code))
+    modulename = signature
+    moduleids = [signature]
+    module_path = os.path.join(get_temp_dir(), modulename)
+
+
+    os.mkdir(module_path)
+    os.chdir(module_path)
+
+    write_cmakefile(modulename)
+    s = generate_interface_file_vtk(signature, c_code)
+    write_vtk_interface_file(signature, c_code)
+
+    ret, output = get_status_output("cmake -DDEBUG=TRUE . > cmake.log ")
+    ret, output = get_status_output("make > compile.log ")
+
+    module_path = copy_to_cache(module_path, cache_dir, modulename)
+
+    os.chdir(original_path)
+    lock = get_lock(cache_dir, modulename)
+
+    module = import_and_cache_module(module_path, modulename, moduleids)
+    release_lock(lock)
+
+    return module
+      
+def build_module_vmtk(c_code, cache_dir=None): 
+    original_path = os.getcwd()
+    cache_dir = validate_cache_dir(cache_dir)
+    signature = modulename_from_checksum(compute_checksum(c_code))
+    modulename = signature
+    moduleids = [signature]
+    module_path = os.path.join(get_temp_dir(), modulename)
+
+
+    os.mkdir(module_path)
+    os.chdir(module_path)
+
+    write_vmtk_cmakefile(modulename)
+    s = generate_interface_file_vtk(signature, c_code)
+    write_vtk_interface_file(signature, c_code)
+
+    ret, output = get_status_output("cmake -DDEBUG=TRUE . > cmake.log ")
+    ret, output = get_status_output("make > compile.log ")
+
+    module_path = copy_to_cache(module_path, cache_dir, modulename)
+
+    os.chdir(original_path)
+    lock = get_lock(cache_dir, modulename)
+
+    module = import_and_cache_module(module_path, modulename, moduleids)
+    release_lock(lock)
+
+    return module
+      
+    
+
+
+
